@@ -37,7 +37,7 @@ import warnings
 ## As suggested in https://shapely.readthedocs.io/en/latest/migration.html
 warnings.filterwarnings(
     action='ignore',
-    category=DeprecationWarning,
+    category=ShapelyDeprecationWarning,
     module='descartes'
 )
 
